@@ -12,7 +12,7 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library.  If not, see 
+   Public License along with this library.  If not, see
    <http://www.gnu.org/licenses/>. */
 
 #if HAVE_CONFIG_H
@@ -71,7 +71,7 @@ mu_get_full_path (const char *file)
    into an equivalent absolute path. Strip trailing delimiter if present,
    unless it is the only character left. E.g.:
 
-         /home/user/../smith   -->   /home/smith
+	 /home/user/../smith   -->   /home/smith
 	 /home/user/../..      -->   /
 
 */
@@ -133,7 +133,7 @@ mu_normalize_path (char *path)
 
 /* Expand a PATTERN to the pathname. PATTERN may contain the following
    macro-notations:
-   ---------+------------ 
+   ---------+------------
    notation |  expands to
    ---------+------------
    %u         user name
@@ -141,7 +141,7 @@ mu_normalize_path (char *path)
    ~          Likewise
    ---------+------------
 
-   Allocates memory. 
+   Allocates memory.
 */
 char *
 mu_expand_path_pattern (const char *pattern, const char *username)
@@ -151,26 +151,26 @@ mu_expand_path_pattern (const char *pattern, const char *username)
   char *path;
   size_t len = 0;
   struct mu_auth_data *auth = NULL;
-  
+
   for (p = pattern; *p; p++)
     {
       if (*p == '~')
-        {
-          if (!auth)
-            {
-              auth = mu_get_auth_by_name (username);
-              if (!auth)
-                return NULL;
-            }
-          len += strlen (auth->dir);
-        }
+	{
+	  if (!auth)
+	    {
+	      auth = mu_get_auth_by_name (username);
+	      if (!auth)
+		return NULL;
+	    }
+	  len += strlen (auth->dir);
+	}
       else if (*p == '%')
 	switch (*++p)
 	  {
 	  case 'u':
 	    len += strlen (username);
 	    break;
-	    
+
 	  case 'h':
 	    if (!auth)
 	      {
@@ -180,18 +180,18 @@ mu_expand_path_pattern (const char *pattern, const char *username)
 	      }
 	    len += strlen (auth->dir);
 	    break;
-	    
+
 	  case '%':
 	    len++;
 	    break;
-	    
+
 	  default:
 	    len += 2;
 	  }
       else
 	len++;
     }
-  
+
   path = malloc (len + 1);
   if (!path)
     return NULL;
@@ -218,16 +218,16 @@ mu_expand_path_pattern (const char *pattern, const char *username)
 	      strcpy (q, username);
 	      q += strlen (username);
 	      break;
-	    
+
 	    case 'h':
 	      strcpy (q, auth->dir);
 	      q += strlen (auth->dir);
 	      break;
-	  
+
 	    case '%':
 	      *q++ = '%';
 	      break;
-	  
+
 	    default:
 	      *q++ = '%';
 	      *q++ = *p;
@@ -241,3 +241,39 @@ mu_expand_path_pattern (const char *pattern, const char *username)
     mu_auth_data_free (auth);
   return path;
 }
+
+/*
+ * Split FILENAME into directory and basename parts.  If DIRNAME is not
+ * NULL, store there the directory part (or NULL, if there is none).  If
+ * BASENAME is not NULL, store there the basename part.  Values returned
+ * in these variables are allocated, the caller is supposed to free them
+ * when no longer needed.
+ *
+ * Return a pointer to the basename part in FILENAME.  On error (unable to
+ * allocate memory), return NULL.
+ */
+char const *
+mu_filename_split (char const *filename, char **dirname, char **basename)
+{
+  char *p = strrchr (filename, '/');
+  char const *bname = p ? p + 1 : filename;
+  if (dirname)
+    {
+      if (p == NULL)
+	*dirname = NULL;
+      else
+	{
+	  if ((*dirname = strndup (filename, p - filename)) == NULL)
+	    return NULL;
+	}
+    }
+  if (basename)
+    {
+      if ((*basename = strdup (bname)) == NULL)
+	{
+	  free (*dirname);
+	  return NULL;
+	}
+    }
+  return bname;
+}
