@@ -342,14 +342,15 @@ flush_stream (struct burst_stream *bs, char *buf, size_t size)
       if (!bs->flags)
 	mu_stream_write (bs->stream, "\n", 1, NULL);
 
-      if (verbose && !inplace)
+      if (!inplace)
 	{
 	  size_t nextuid;
 	  mu_mailbox_uidnext (tmpbox, &nextuid);
-	  printf (_("message %lu of digest %lu becomes message %lu\n"),
-		  (unsigned long) bs->partno,
-		  (unsigned long) bs->msgno,
-		  (unsigned long) nextuid);
+
+	  VERBOSE((_("message %s of digest %s becomes message %s"),
+		   mu_umaxtostr_n (0, bs->partno),
+		   mu_umaxtostr_n (1, bs->msgno),
+		   mu_umaxtostr_n (2, nextuid)));
 	}
     }
   rc = mu_stream_write (bs->stream, buf, size, NULL);
