@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2021 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ static struct mu_option options[] = {
     N_("use MIME encapsulation"),
     mu_c_bool, NULL, set_mime },
   { "width",         0, N_("NUMBER"), MU_OPTION_DEFAULT,
-    N_("Set output width"),
+    N_("set output width"),
     mu_c_int, &width },
   { "whatnowproc",   0, N_("PROG"), MU_OPTION_DEFAULT,
     N_("set the replacement for whatnow program"),
@@ -273,8 +273,8 @@ finish_draft ()
 				   wh_env.file,
 				   MU_STREAM_WRITE|MU_STREAM_CREAT)))
     {
-      mu_error (_("cannot open output file `%s': %s"),
-		wh_env.file, mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create",
+		       wh_env.file, rc);
       exit (1);
     }
 
@@ -289,8 +289,8 @@ finish_draft ()
 				       wh_env.file,
 				       MU_STREAM_WRITE|MU_STREAM_CREAT)))
 	{
-	  mu_error (_("cannot open output file `%s': %s"),
-		    wh_env.file, mu_strerror (rc));
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create",
+			   wh_env.file, rc);
 	  exit (1);
 	}
 
@@ -402,7 +402,7 @@ main (int argc, char **argv)
 	}
       if (argc)
 	{
-	  mu_error (_("can't mix files and folders/msgs"));
+	  mu_error (_("cannot mix files and folders/msgs"));
 	  exit (1);
 	}
     }
@@ -444,8 +444,10 @@ main (int argc, char **argv)
 	  rc = mu_rename_file (wh_env.file, wh_env.draftfile, MU_COPY_OVERWRITE);
 	  if (rc)
 	    {
-	      mu_error (_("can't rename %s to %s: %s"),
-			wh_env.file, wh_env.draftfile, mu_strerror (rc));
+	      mu_error (_("cannot rename %s to %s: %s"),
+			mu_quotename_n (0, wh_env.file),
+			mu_quotename_n (1, wh_env.draftfile),
+			mu_strerror (rc));
 	      return 1;
 	    }
 	}
