@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002-2024 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ mhpath (size_t num, mu_message_t msg, void *data)
   size_t uid;
   
   mh_message_number (msg, &uid);
-  printf ("%s/%s\n", (char*) data, mu_umaxtostr (0, uid));
+  printf ("%s/%s\n", (char*) data, mu_umaxtostr (uid));
   return 0;
 }
 
@@ -85,7 +85,7 @@ main (int argc, char **argv)
       
       mu_mailbox_get_message (mbox, total, &msg);
       mh_message_number (msg, &num);
-      printf ("%s/%s\n", mhdir, mu_umaxtostr (0, num + 1));
+      printf ("%s/%s\n", mhdir, mu_umaxtostr (num + 1));
       exit (0);
     }
       
