@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2023 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -203,8 +203,7 @@ checkdraft (const char *name)
   
   if (stat (name, &st))
     {
-      mu_error (_("unable to stat draft file %s: %s"), name,
-		mu_strerror (errno));
+      mu_diag_funcall (MU_DIAG_ERROR, "stat", name, errno);
       return 1;
     }
   return 0;
@@ -347,7 +346,7 @@ open_mailer ()
   status = mu_mailer_create (&mailer, url);
   if (status)
     {
-      mu_error (_("cannot create mailer `%s'"), url);
+      mu_error (_("cannot create mailer %s"), mu_quotename (url));
       return NULL;
     }
 
@@ -361,7 +360,8 @@ open_mailer ()
   status = mu_mailer_open (mailer, MU_STREAM_RDWR);
   if (status)
     {
-      mu_error (_("cannot open mailer `%s': %s"), url, mu_strerror (status));
+      mu_error (_("cannot open mailer %s: %s"), mu_quotename (url),
+		mu_strerror (status));
       return NULL;
     }
   return mailer;
@@ -449,7 +449,7 @@ fix_fcc (mu_message_t msg)
       if (mu_wordsplit (fcc, &ws,
 			MU_WRDSF_DEFFLAGS | MU_WRDSF_DELIM | MU_WRDSF_WS))
 	{
-	  mu_error (_("cannot split line `%s': %s"), fcc,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (fcc),
 		    mu_wordsplit_strerror (&ws));
 	}
       else
@@ -566,7 +566,8 @@ backup_file (const char *file_name)
       int rc = mu_rename_file (file_name, new_name, MU_COPY_OVERWRITE);
       if (rc)
 	mu_error (_("cannot rename %s to %s: %s"),
-		  file_name, new_name, mu_strerror (errno));
+		  mu_quotename_n (0, file_name),
+		  mu_quotename_n (1, new_name), mu_strerror (errno));
     }
   free (new_name);
 }
@@ -681,7 +682,7 @@ _add_to_mesg_list (size_t num, mu_message_t msg, void *data)
     }
 
   mu_message_get_uid (msg, &uid);
-  file_name = mu_make_file_name (path, mu_umaxtostr (0, uid));
+  file_name = mu_make_file_name (path, mu_umaxtostr (uid));
   if (!use_draft)
     {
       if (!mh_usedraft (file_name))
